Supertester.Env behaviour (Supertester v0.6.0)

Copy Markdown View Source

Environment abstraction that Supertester uses to integrate with the host test runner.

By default, Supertester.Env delegates to ExUnit.Callbacks.on_exit/1. Custom harnesses can provide their own implementation via the :supertester, :env_module application configuration.

Summary

Functions

Registers a callback to run when the current test finishes.

Callbacks

on_exit(function)

@callback on_exit((-> any())) :: :ok

Functions

on_exit(callback)

@spec on_exit((-> any())) :: :ok

Registers a callback to run when the current test finishes.