Supertester.ExUnitFoundation (Supertester v0.6.0)

Copy Markdown View Source

Thin ExUnit adapter that wires Supertester.UnifiedTestFoundation into ExUnit.Case.

Use this module from your test cases to enable Supertester isolation while keeping the ergonomics of use ExUnit.Case. All isolation options supported by Supertester.UnifiedTestFoundation are available via the :isolation option.

Example

defmodule MyApp.MyTest do
  use Supertester.ExUnitFoundation, isolation: :full_isolation

  test "works concurrently", context do
    assert context.isolation_context.test_id
  end
end