Supertester.Telemetry (Supertester v0.6.0)

Copy Markdown View Source

Centralized Telemetry instrumentation for Supertester.

All public helpers eventually call :telemetry.execute/3 with the [:supertester | event] prefix so consumers can subscribe to a consistent namespace.

Summary

Functions

Emits a raw telemetry event with the [:supertester | event] prefix.

Emits mailbox sampling metrics captured during a scenario.

Emits performance measurements produced for a scenario.

Emits the scenario start event for the concurrent harness.

Emits the scenario stop event for the concurrent harness.

Types

measurements()

@type measurements() :: map()

metadata()

@type metadata() :: map()

Functions

chaos_event(type, measurements \\ %{}, metadata \\ %{})

@spec chaos_event(:start | :stop, measurements(), metadata()) :: :ok

Emits chaos lifecycle events.

emit(event, measurements \\ %{}, metadata \\ %{})

@spec emit([atom()], measurements(), metadata()) :: :ok

Emits a raw telemetry event with the [:supertester | event] prefix.

mailbox_sample(measurements, metadata \\ %{})

@spec mailbox_sample(measurements(), metadata()) :: :ok

Emits mailbox sampling metrics captured during a scenario.

performance_event(measurements, metadata \\ %{})

@spec performance_event(measurements(), metadata()) :: :ok

Emits performance measurements produced for a scenario.

scenario_start(metadata \\ %{})

@spec scenario_start(metadata()) :: :ok

Emits the scenario start event for the concurrent harness.

scenario_stop(measurements \\ %{}, metadata \\ %{})

@spec scenario_stop(measurements(), metadata()) :: :ok

Emits the scenario stop event for the concurrent harness.