Centralized Telemetry instrumentation for Supertester.
All public helpers eventually call :telemetry.execute/3 with the [:supertester | event]
prefix so consumers can subscribe to a consistent namespace.
Summary
Functions
Emits chaos lifecycle events.
Emits a raw telemetry event with the [:supertester | event] prefix.
Emits mailbox sampling metrics captured during a scenario.
Emits performance measurements produced for a scenario.
Emits the scenario start event for the concurrent harness.
Emits the scenario stop event for the concurrent harness.
Types
Functions
@spec chaos_event(:start | :stop, measurements(), metadata()) :: :ok
Emits chaos lifecycle events.
@spec emit([atom()], measurements(), metadata()) :: :ok
Emits a raw telemetry event with the [:supertester | event] prefix.
@spec mailbox_sample(measurements(), metadata()) :: :ok
Emits mailbox sampling metrics captured during a scenario.
@spec performance_event(measurements(), metadata()) :: :ok
Emits performance measurements produced for a scenario.
@spec scenario_start(metadata()) :: :ok
Emits the scenario start event for the concurrent harness.
@spec scenario_stop(measurements(), metadata()) :: :ok
Emits the scenario stop event for the concurrent harness.